@@ -113,10 +113,7 @@ action_shellConfigureNotify(w, event, params, num_params)
 /* action_page */
 /*##################################################################*/
 
-static int scroll_success(clip,e,x,y,nx,ny)
-  Widget clip;
-  int e;
-  int x,y;
+static int scroll_success(Widget clip, int e, int x, int y, int nx, int ny)
 {
   int tx,ty;
   ClipWidgetCheckCoordinates(clip,nx,ny,&tx,&ty);
@@ -799,6 +796,23 @@ action_reopen(w, event, params, num_params)
   ENDMESSAGE(action_reopen)
 }
 
+/*##################################################################*/
+/* action_savepos */
+/*##################################################################*/
+
+void
+action_savepos(w, event, params, num_params)
+  Widget w;
+  XEvent *event;
+  String *params;
+  Cardinal *num_params;
+{
+  BEGINMESSAGE(action_savepos)
+  if (!XtIsSensitive(saveposEntry)) {INFMESSAGE(insensitive) ENDMESSAGE(action_savepos) return; }
+  cb_savepos((Widget)NULL,(XtPointer)NULL,(XtPointer)NULL);
+  ENDMESSAGE(action_savepos)
+}
+
 /*##################################################################*/
 /* action_save */
 /* Popup the save file dialog box. */
@@ -874,6 +888,19 @@ action_print(w, event, params, num_params)
     ENDMESSAGE(action_print)
 }
 
+void
+action_print_pos(w, event, params, num_params)
+    Widget w;
+    XEvent *event;
+    String *params;
+    Cardinal *num_params;
+{
+
+    BEGINMESSAGE(action_print_pos)
+    cb_print_pos((Widget)NULL,0,NULL);
+    ENDMESSAGE(action_print_pos)
+}
+
 /*##################################################################*/
 /* action_setPageMark */
 /* Call the cb_setPageMark callback */
