@@ -405,6 +405,7 @@ static void watch_file (client_data, idp)
       int error;
       String s;
       struct stat sbuf;
+
       INFMESSAGE(checking file)
       s = GV_XtNewString(gv_filename);
       error = stat(s, &sbuf);
@@ -557,6 +558,7 @@ cb_print_pos(w, client_data, call_data)
     XtPointer client_data, call_data;
 {
     char *pagelist=NULL;
+    static char buf[MAX_LOCATOR_LENGTH];
 
     BEGINMESSAGE(cb_print_pos)
 
@@ -575,7 +577,6 @@ cb_print_pos(w, client_data, call_data)
     DialogPopupSetButton(DIALOG_BUTTON_DONE,"Save",cb_doPrintPos);
     DialogPopupSetButton(DIALOG_BUTTON_CANCEL,NULL,cb_cancelPrint);
 
-    static char buf[MAX_LOCATOR_LENGTH];
     sprintf(buf, "\\PutAtPos(%i,%i){%s}", last_psx, last_psy, "") ;
     DialogPopupSetText(buf);
     cb_popupDialogPopup((Widget)NULL,NULL,NULL);
@@ -588,6 +589,7 @@ cb_doPrintPos(w, client_data, call_data)
     XtPointer client_data, call_data;
 {
     String print_command;
+    FILE* posfile = fopen(gv_savepos_filename, "a");
 
     BEGINMESSAGE(cb_doPrintPos)
 
@@ -595,8 +597,6 @@ cb_doPrintPos(w, client_data, call_data)
     print_command = DialogPopupGetText(); /* dialog was used */  
     if (!print_command) print_command="";
 
-    FILE* posfile = fopen(gv_savepos_filename, "a");
-
     if (posfile == NULL) {
        INFMESSAGE(cannot open file for writting)
        ENDMESSAGE(cb_doPrintPos)
@@ -1488,3 +1488,49 @@ cb_doQuit(w, client_data, call_data)
   XtDestroyWidget(toplevel);
   ENDMESSAGE(cb_doQuit)
 }
+
+/*##################################################################*/
+/* cb_setPassword */
+/*##################################################################*/
+
+static void
+cb_setPassword(Widget w, XtPointer client_data, XtPointer call_data)
+{
+    String password;
+
+    password = DialogPopupGetText();
+    if (!password) password="";
+
+    if (gv_pdf_password)
+      GV_XtFree(gv_pdf_password);
+    gv_pdf_password = GV_XtNewString(password);
+
+    cb_popdownDialogPopup((Widget)NULL,(XtPointer)NULL,NULL);
+    cb_reopen(page,0,0);
+}
+
+/*##################################################################*/
+/* cb_cancelPassword */
+/*##################################################################*/
+
+static void
+cb_cancelPassword(Widget w, XtPointer client_data, XtPointer call_data)
+{
+    cb_popdownDialogPopup((Widget)NULL,(XtPointer)NULL,NULL);
+}
+
+/*##################################################################*/
+/* cb_askPassword */
+/* Ask for the password needed to view a pdf file */
+/*##################################################################*/
+void
+cb_askPassword(Widget w, XtPointer client_data, XtPointer call_data)
+{
+  DialogPopupSetPrompt("Password:");
+  DialogPopupSetMessage("Password required");
+  DialogPopupSetButton(DIALOG_BUTTON_DONE,NULL,cb_setPassword);
+  DialogPopupSetButton(DIALOG_BUTTON_CANCEL,NULL,cb_cancelPassword);
+  DialogPopupSetText("");
+  cb_popupDialogPopup((Widget)NULL,NULL,NULL);
+  return;
+}
