@@ -6,7 +6,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -28,6 +28,8 @@
 **           GNU Project
 */
 
+#include "ac_config.h"
+
 #include "config.h"
 
 #include <stdio.h>
@@ -151,7 +153,7 @@ static char *tabTrans =
 <MapNotify>:display-caret(on,always)\
 ";
 
-void makeDialogPopup()
+void makeDialogPopup(void)
 {
    Arg          args[7];
    Cardinal     n;
@@ -245,7 +247,7 @@ void DialogPopupSetButton(button,label,callback)
     DialogPopupClearText
 ###############################################################################*/
 
-void DialogPopupClearText()
+void DialogPopupClearText(void)
  {
     Arg args[5];
     Cardinal n;
@@ -311,7 +313,7 @@ void DialogPopupSetText(s)
     DialogPopupGetText
 ###############################################################################*/
  
-String DialogPopupGetText()
+String DialogPopupGetText(void)
 {
     Arg args[5];
     Cardinal n;
